==> core-1.8.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/core/Intrinsic.java <==
package software.amazon.awscdk.core;

/**
 * Token subclass that represents values intrinsic to the target document language.
 * 
 * WARNING: this class should not be externally exposed, but is currently visible
 * because of a limitation of jsii (https://github.com/aws/jsii/issues/524).
 * 
 * This class will disappear in a future release and should not be used.
 * 
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.16.0 (build 98909b5)", date = "2019-09-10T21:04:46.917Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.Intrinsic")
public class Intrinsic extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.core.IResolvable {

    protected Intrinsic(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Intrinsic(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }
    /**
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Intrinsic(final java.lang.Object value) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        this.setObjRef(software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { value }));
    }

    /**
     * Creates a throwable Error object that contains the token creation stack trace.
     * 
     * EXPERIMENTAL
     * 
     * @param message Error message.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    protected java.lang.Object newError(final java.lang.String message) {
        return this.jsiiCall("newError", java.lang.Object.class, new Object[] { java.util.Objects.requireNonNull(message, "message is required") });
    }

    /**
     * Produce the Token's value at resolution time.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    public java.lang.Object resolve(final software.amazon.awscdk.core.IResolveContext _context) {
        return this.jsiiCall("resolve", java.lang.Object.class, new Object[] { java.util.Objects.requireNonNull(_context, "_context is required") });
    }

    /**
     * Turn this Token into JSON.
     * 
     * Called automatically when JSON.stringify() is called on a Token.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.lang.Object toJSON() {
        return this.jsiiCall("toJSON", java.lang.Object.class);
    }

    /**
     * Convert an instance of this Token to a string.
     * 
     * This method will be called implicitly by language runtimes if the object
     * is embedded into a string. We treat it the same as an explicit
     * stringification.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    public java.lang.String toString() {
        return this.jsiiCall("toString", java.lang.String.class);
    }

    /**
     * The captured stack trace which represents the location in which this token was created.
     * 
     * EXPERIMENTAL
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.util.List<java.lang.String> getCreationStack() {
        return this.jsiiGet("creationStack", java.util.List.class);
    }
}

==> core-1.9.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/core/Intrinsic.java <==
package software.amazon.awscdk.core;

/**
 * Token subclass that represents values intrinsic to the target document language.
 * 
 * WARNING: this class should not be externally exposed, but is currently visible
 * because of a limitation of jsii (https://github.com/aws/jsii/issues/524).
 * 
 * This class will disappear in a future release and should not be used.
 * 
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.17.0 (build 7d5d104)", date = "2019-09-20T09:44:35.466Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.Intrinsic")
public class Intrinsic extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.core.IResolvable {

    protected Intrinsic(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Intrinsic(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * EXPERIMENTAL
     * 
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Intrinsic(final java.lang.Object value) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        this.setObjRef(software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { value }));
    }

    /**
     * Creates a throwable Error object that contains the token creation stack trace.
     * 
     * EXPERIMENTAL
     * 
     * @param message Error message. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    protected java.lang.Object newError(final java.lang.String message) {
        return this.jsiiCall("newError", java.lang.Object.class, new Object[] { java.util.Objects.requireNonNull(message, "message is required") });
    }

    /**
     * Produce the Token's value at resolution time.
     * 
     * EXPERIMENTAL
     * 
     * @param _context This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    public java.lang.Object resolve(final software.amazon.awscdk.core.IResolveContext _context) {
        return this.jsiiCall("resolve", java.lang.Object.class, new Object[] { java.util.Objects.requireNonNull(_context, "_context is required") });
    }

    /**
     * Turn this Token into JSON.
     * 
     * Called automatically when JSON.stringify() is called on a Token.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.lang.Object toJSON() {
        return this.jsiiCall("toJSON", java.lang.Object.class);
    }

    /**
     * Convert an instance of this Token to a string.
     * 
     * This method will be called implicitly by language runtimes if the object
     * is embedded into a string. We treat it the same as an explicit
     * stringification.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    public java.lang.String toString() {
        return this.jsiiCall("toString", java.lang.String.class);
    }

    /**
     * The captured stack trace which represents the location in which this token was created.
     * 
     * EXPERIMENTAL
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.util.List<java.lang.String> getCreationStack() {
        return java.util.Collections.unmodifiableList(this.jsiiGet("creationStack", java.util.List.class));
    }
}
